@@ -2,6 +2,7 @@
 
 from .sisl_lexer import *
 from .sisl_parser import *
+from .sisl_joiner import *
 
 import ply.lex as lex
 import ply.yacc as yacc
@@ -18,7 +19,12 @@ class SislDecoder:
         lex.lex()
 
     def loads(self, sisl, schema=None):
-        flattened_sisl = sisl_type_flatten.SISLTypeFlatten().flatten(self.parse_raw_types(sisl))
+        if type(sisl) is list:
+            sisl = JoinSisl.join([self.parse_raw_types(parsed_sisl) for parsed_sisl in sisl])
+        else:
+            sisl = self.parse_raw_types(sisl)
+
+        flattened_sisl = sisl_type_flatten.SISLTypeFlatten().flatten(sisl)
         self._verify_schema_if_required(flattened_sisl, schema)
         return flattened_sisl
 
