@@ -20,7 +20,7 @@ class SISLTypeFlatten:
     @classmethod
     def _type_cast_mappings(cls):
         return {
-            "str": lambda type_value: str(type_value["value"]).replace('\\"', '\"').replace('\\\\', '\\'),
+            "str": cls._convert_string,
             "obj": lambda type_value: cls.flatten(type_value["value"]),
             "bool": cls._convert_bool,
             "int": lambda type_value: int(type_value["value"]),
@@ -29,6 +29,10 @@ class SISLTypeFlatten:
             "null": lambda type_value: None
         }
 
+    @staticmethod
+    def _convert_string(type_value):
+        return str(type_value['value']).replace(r'\"', r'"').encode().decode('unicode_escape')
+
     @staticmethod
     def _convert_bool(type_value):
         if type_value["value"] == "true":
