@@ -62,6 +62,15 @@ class SislParsingTests(unittest.TestCase):
     def test_escaped_dbquote_successful_converted_to_sisl(self):
         self.assertEqual(r'{field_one: !str "te\"st"}', SislEncoder.dumps({"field_one": "te\"st"}))
 
+    def test_8_bit_unicode_characters(self):
+        self.assertEqual(r'{field_one: !str "\xe7\xe4"}', SislEncoder.dumps({"field_one": "çä"}))
+
+    def test_16_bit_unicode_characters(self):
+        self.assertEqual(r'{field_one: !str "\u04e7\u02b6"}', SislEncoder.dumps({"field_one": "ӧʶ"}))
+
+    def test_32_bit_unicode_characters(self):
+        self.assertEqual(r'{field_one: !str "\U0001f602\U0001f525"}', SislEncoder.dumps({"field_one": "😂🔥"}))
+
     def test_list_tuple_value_successfully_converted_to_sisl(self):
         # [value1, value2]
         self.assertEqual("{field_one: !list {_0: !str \"value1\", _1: !str \"value2\"}}",
